@@ -205,7 +205,7 @@ struct _GstASFDemux {
   gboolean             broadcast;
 
   GstSegment           segment;          /* configured play segment                 */
-  gboolean             accurate;
+  gboolean             keyunit_sync;
 
   gboolean             need_newsegment;  /* do we need to send a new-segment event? */
   guint32              segment_seqnum;   /* if the new segment must have this seqnum */
